@@ -136,16 +136,16 @@ def get_parameter_elasticity(
 
     Also called pi-elasticities. Not in steady state!
     """
-    model = model.copy()
-    old_value = model.get_parameter(parameter_name=parameter)
+    model_copy: Model = model.copy()
+    old_value = model_copy.get_parameter(parameter_name=parameter)
     fluxes = []
     for new_value in [old_value * (1 + displacement), old_value * (1 - displacement)]:
-        model.update_parameter(parameter_name=parameter, parameter_value=new_value)
-        fluxes.append(model.get_fluxes_array(y=y, t=t))
+        model_copy.update_parameter(parameter_name=parameter, parameter_value=new_value)
+        fluxes.append(model_copy.get_fluxes_array(y=y, t=t))
     elasticity_coef = (fluxes[0] - fluxes[1]) / (2 * displacement * old_value)
     if normalized:
-        model.update_parameter(parameter_name=parameter, parameter_value=old_value)
-        fluxes_array = model.get_fluxes_array(y=y, t=t)
+        model_copy.update_parameter(parameter_name=parameter, parameter_value=old_value)
+        fluxes_array = model_copy.get_fluxes_array(y=y, t=t)
         elasticity_coef *= old_value / fluxes_array
     return cast(Array, np.atleast_1d(np.squeeze(elasticity_coef)))
 
@@ -232,11 +232,12 @@ def get_response_coefficients(
     **integrator_kwargs: Dict[str, Any],
 ) -> Tuple[Optional[Array], Optional[Array]]:
     """Get response of the steady state concentrations and fluxes to a change of the given parameter."""
-    model = model.copy()
-    old_value = model.get_parameter(parameter_name=parameter)
+
+    model_copy: Model = model.copy()
+    old_value = model_copy.get_parameter(parameter_name=parameter)
     if normalized:
         t_ss, y_ss = _find_steady_state(
-            model=model,
+            model=model_copy,
             y0=y,
             tolerance=tolerance,
             simulation_kwargs=simulation_kwargs,
@@ -244,8 +245,8 @@ def get_response_coefficients(
         )
         if t_ss is None or y_ss is None:
             return None, None
-        fluxes_array_norm = model.get_fluxes_array(y=y_ss, t=t_ss)
-        fcd = model.get_full_concentration_dict(y_ss)
+        fluxes_array_norm = model_copy.get_fluxes_array(y=y_ss, t=t_ss)
+        fcd = model_copy.get_full_concentration_dict(y_ss)
         del fcd["time"]
         y_ss_norm = old_value / np.fromiter(fcd.values(), dtype="float")
         fluxes_array_norm = old_value / fluxes_array_norm
@@ -256,9 +257,9 @@ def get_response_coefficients(
         old_value * (1 + displacement),
         old_value * (1 - displacement),
     ]:
-        model.update_parameter(parameter_name=parameter, parameter_value=new_value)
+        model_copy.update_parameter(parameter_name=parameter, parameter_value=new_value)
         t_ss, y_ss = _find_steady_state(
-            model=model,
+            model=model_copy,
             y0=y,
             tolerance=tolerance,
             simulation_kwargs=simulation_kwargs,
@@ -266,10 +267,10 @@ def get_response_coefficients(
         )
         if t_ss is None or y_ss is None:
             return None, None
-        fcd = model.get_full_concentration_dict(y_ss)
+        fcd = model_copy.get_full_concentration_dict(y_ss)
         del fcd["time"]
         ss.append(np.fromiter(fcd.values(), dtype="float"))
-        fluxes.append(model.get_fluxes_array(y=y_ss, t=t_ss))
+        fluxes.append(model_copy.get_fluxes_array(y=y_ss, t=t_ss))
 
     conc_resp_coef: Array = (ss[0] - ss[1]) / (2 * displacement * old_value)
     flux_resp_coef: Array = (fluxes[0] - fluxes[1]) / (2 * displacement * old_value)
